@@ -30,7 +30,6 @@ import ceilometer.ipmi.platform.intel_node_manager
 import ceilometer.ipmi.pollsters
 import ceilometer.keystone_client
 import ceilometer.meter.notifications
-import ceilometer.middleware
 import ceilometer.neutron_client
 import ceilometer.notification
 import ceilometer.nova_client
@@ -70,8 +69,7 @@ def list_opts():
     # This have been removed due to a recursive import issue
     return [
         ('DEFAULT',
-         itertools.chain(ceilometer.polling.manager.OPTS,
-                         ceilometer.compute.virt.inspector.OPTS,
+         itertools.chain(ceilometer.compute.virt.inspector.OPTS,
                          ceilometer.compute.virt.libvirt.utils.OPTS,
                          ceilometer.objectstore.swift.OPTS,
                          ceilometer.pipeline.base.OPTS,
@@ -93,28 +91,6 @@ def list_opts():
                 help='Number of seconds between checks to see if group '
                 'membership has changed'),
         ]),
-        ('dispatcher_gnocchi', (
-         cfg.StrOpt(
-             'filter_project',
-             deprecated_for_removal=True,
-             default='gnocchi',
-             help='Gnocchi project used to filter out samples '
-             'generated by Gnocchi service activity'),
-         cfg.StrOpt(
-             'archive_policy',
-             deprecated_for_removal=True,
-             help='The archive policy to use when the dispatcher '
-             'create a new metric.'),
-         cfg.StrOpt(
-             'resources_definition_file',
-             deprecated_for_removal=True,
-             default='gnocchi_resources.yaml',
-             help=('The Yaml file that defines mapping between samples '
-                   'and gnocchi resources/metrics')),
-         cfg.FloatOpt(
-             'request_timeout', default=6.05, min=0.0,
-             deprecated_for_removal=True,
-             help='Number of seconds before request to gnocchi times out'))),
         ('event', ceilometer.event.converter.OPTS),
         ('hardware', itertools.chain(
             ceilometer.hardware.discovery.OPTS,
@@ -130,6 +106,7 @@ def list_opts():
         ('publisher', ceilometer.publisher.utils.OPTS),
         ('publisher_notifier', ceilometer.publisher.messaging.NOTIFIER_OPTS),
         ('rgw_admin_credentials', ceilometer.objectstore.rgw.CREDENTIAL_OPTS),
+        ('rgw_client', ceilometer.objectstore.rgw.CLIENT_OPTS),
         ('service_types',
          itertools.chain(ceilometer.image.discovery.SERVICE_OPTS,
                          ceilometer.neutron_client.SERVICE_OPTS,
