@@ -44,12 +44,13 @@ INSTANCE_DELETE_START = models.Event(
             models.Trait(
                 'user_id', 1, u'1e3ce043029547f1a61c1996d1a531a2'),
             models.Trait('service', 1, u'compute'),
+            models.Trait('availability_zone', 1, u'zone1'),
             models.Trait('disk_gb', 2, 0),
             models.Trait('instance_type', 1, u'm1.tiny'),
             models.Trait('tenant_id', 1, u'7c150a59fe714e6f9263774af9688f0e'),
             models.Trait('root_gb', 2, 0),
             models.Trait('ephemeral_gb', 2, 0),
-            models.Trait('instance_type_id', 2, 2),
+            models.Trait('instance_type_id', 2, u'2'),
             models.Trait('vcpus', 2, 1),
             models.Trait('memory_mb', 2, 512),
             models.Trait(
@@ -64,6 +65,33 @@ INSTANCE_DELETE_START = models.Event(
     message_id=u'a15b94ee-cb8e-4c71-9abe-14aa80055fb4',
 )
 
+INSTANCE_CREATE_END = models.Event(
+    event_type=u'compute.instance.create.end',
+    traits=[models.Trait('state', 1, u'active'),
+            models.Trait(
+                'user_id', 1, u'1e3ce043029547f1a61c1996d1a531a2'),
+            models.Trait('service', 1, u'compute'),
+            models.Trait('availability_zone', 1, u'zone1'),
+            models.Trait('disk_gb', 2, 0),
+            models.Trait('instance_type', 1, u'm1.tiny'),
+            models.Trait('tenant_id', 1, u'7c150a59fe714e6f9263774af9688f0e'),
+            models.Trait('root_gb', 2, 0),
+            models.Trait('ephemeral_gb', 2, 0),
+            models.Trait('instance_type_id', 2, u'2'),
+            models.Trait('vcpus', 2, 1),
+            models.Trait('memory_mb', 2, 512),
+            models.Trait(
+                'instance_id', 1, u'9f9d01b9-4a58-4271-9e27-398b21ab20d1'),
+            models.Trait('host', 1, u'vagrant-precise'),
+            models.Trait(
+                'request_id', 1, u'req-fb3c4546-a2e5-49b7-9fd2-a63bd658bc39'),
+            models.Trait('project_id', 1, u'7c150a59fe714e6f9263774af9688f0e'),
+            models.Trait('launched_at', 4, '2012-05-08T20:23:47')],
+    raw={},
+    generated='2012-05-08T20:24:14.824743',
+    message_id=u'202f745e-4913-11e9-affe-9797342bd3a8',
+)
+
 IMAGE_DELETE_START = models.Event(
     event_type=u'image.delete',
     traits=[models.Trait(u'status', 1, u'deleted'),
@@ -178,6 +206,9 @@ class PublisherTest(base.BaseTestCase):
         self.useFixture(fixtures.MockPatch(
             'gnocchiclient.v1.client.Client',
             return_value=mock.Mock()))
+        self.useFixture(fixtures.MockPatch(
+            'ceilometer.keystone_client.get_session',
+            return_value=mock.Mock()))
         self.ks_client = ks_client
 
     def test_config_load(self):
@@ -462,10 +493,13 @@ class PublisherWorkflowTest(base.BaseTestCase,
         self.useFixture(fixtures.MockPatch(
             'ceilometer.keystone_client.get_client',
             return_value=ks_client))
+        self.useFixture(fixtures.MockPatch(
+            'ceilometer.keystone_client.get_session',
+            return_value=ks_client))
         self.ks_client = ks_client
 
     @mock.patch('gnocchiclient.v1.client.Client')
-    def test_event_workflow(self, fakeclient_cls):
+    def test_delete_event_workflow(self, fakeclient_cls):
         url = netutils.urlsplit("gnocchi://")
         self.publisher = gnocchi.GnocchiPublisher(self.conf.conf, url)
 
@@ -521,6 +555,33 @@ class PublisherWorkflowTest(base.BaseTestCase,
         for call in expected_calls:
             self.assertIn(call, fakeclient.mock_calls)
 
+    @mock.patch('gnocchiclient.v1.client.Client')
+    def test_create_event_workflow(self, fakeclient_cls):
+        url = netutils.urlsplit("gnocchi://")
+        self.publisher = gnocchi.GnocchiPublisher(self.conf.conf, url)
+
+        fakeclient = fakeclient_cls.return_value
+
+        now = timeutils.utcnow()
+        self.useFixture(utils_fixture.TimeFixture(now))
+
+        expected_calls = [
+            mock.call.resource.create(
+                'instance',
+                {'id': '9f9d01b9-4a58-4271-9e27-398b21ab20d1',
+                 'user_id': '1e3ce043029547f1a61c1996d1a531a2',
+                 'project_id': '7c150a59fe714e6f9263774af9688f0e',
+                 'availability_zone': 'zone1',
+                 'flavor_name': 'm1.tiny',
+                 'flavor_id': '2',
+                 'host': 'vagrant-precise'}),
+        ]
+
+        self.publisher.publish_events([INSTANCE_CREATE_END])
+        self.assertEqual(1, len(fakeclient.mock_calls))
+        for call in expected_calls:
+            self.assertIn(call, fakeclient.mock_calls)
+
     @mock.patch('ceilometer.publisher.gnocchi.LOG')
     @mock.patch('gnocchiclient.v1.client.Client')
     def test_workflow(self, fakeclient_cls, logger):
